@@ -6,7 +6,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: pget_blk.c,v 1.1 2007/04/17 20:32:12 joel Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -22,9 +22,9 @@
  */
 
 ER pget_blk(
-  VP  *p_blk,
-  ID   mplid,
-  INT  blksz
+  VP  *p_blk __attribute__((unused)),
+  ID   mplid __attribute__((unused)),
+  INT  blksz __attribute__((unused))
 )
 {
   return E_OK;
