@@ -20,8 +20,8 @@ two paragraphs in the transferred software.
 COPYRIGHT IDT CORPORATION 1996
 LICENSED MATERIAL - PROGRAM PROPERTY OF IDT
 
-  $Id: idtcpu.h,v 1.17 2005/02/04 05:38:26 ralf Exp $
-*/ 
+  $Id$
+*/
 
 /*
 ** idtcpu.h -- cpu related defines
@@ -70,7 +70,7 @@ LICENSED MATERIAL - PROGRAM PROPERTY OF IDT
 #define X_VEC	(K0BASE+0x080)		/* xtlbmiss vector */
 #define C_VEC	(K0BASE+0x100)		/* cache error vector */
 #define E_VEC	(K0BASE+0x180)		/* exception vector */
-#else 
+#else
 #error "EXCEPTION VECTORS: unknown ISA level"
 #endif
 #define	R_VEC	(K1BASE+0x1fc00000)	/* reset vector */
@@ -178,12 +178,13 @@ LICENSED MATERIAL - PROGRAM PROPERTY OF IDT
 #define Hit_Set_Virtual_SI               0x1E        /* 7       2 */
 #define Hit_Set_Virtual_SD               0x1F        /* 7       3 */
 
+/* Disabled by chris -- horrible overload of common word.
 #ifndef WAIT
 #define WAIT .word 0x42000020
-#endif /* WAIT */
-
+#endif
+*/
 /* Disabled by joel -- horrible overload of common word.
-#ifndef wait 
+#ifndef wait
 #define wait .word 0x42000020
 #endif wait
 */
@@ -272,12 +273,13 @@ LICENSED MATERIAL - PROGRAM PROPERTY OF IDT
 #define Hit_Set_Virtual_SI               0x1E        /* 7       2 */
 #define Hit_Set_Virtual_SD               0x1F        /* 7       3 */
 
+/* Disabled by chris -- horrible overload of common word.
 #ifndef WAIT
 #define WAIT .word 0x42000020
-#endif /* WAIT */
-
+#endif
+*/
 /* Disabled by joel -- horrible overload of common word.
-#ifndef wait 
+#ifndef wait
 #define wait .word 0x42000020
 #endif wait
 */
