@@ -1,4 +1,4 @@
-/** 
+/**
  *  @file  score/src/timespeclessthan.c
  */
 
@@ -10,7 +10,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: timespeclessthan.c,v 1.1 2007/04/05 21:17:27 joel Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -23,20 +23,20 @@
 #include <rtems/score/timespec.h>
 #include <rtems/score/tod.h>
 
-boolean _Timespec_Less_than(
+bool _Timespec_Less_than(
   const struct timespec *lhs,
   const struct timespec *rhs
 )
 {
   if ( lhs->tv_sec < rhs->tv_sec )
-    return TRUE;
+    return true;
 
   if ( lhs->tv_sec > rhs->tv_sec )
-    return FALSE;
+    return false;
 
   /* ASSERT: lhs->tv_sec == rhs->tv_sec */
   if ( lhs->tv_nsec < rhs->tv_nsec )
-    return TRUE; 
+    return true;
 
-  return FALSE;
+  return false;
 }
