@@ -8,14 +8,14 @@
  *
  *  Output parameters:  NONE
  *
- *  COPYRIGHT (c) 1989-1999.
+ *  COPYRIGHT (c) 1989-2009.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: task2.c,v 1.7 2003/09/04 18:53:47 joel Exp $
+ *  $Id$
  */
 
 #include "system.h"
@@ -32,7 +32,7 @@ rtems_task Task_2(
 
   while( FOREVER ) {
     puts( "TA2 - rtems_task_wake_after - sleep 1 second" );
-    status = rtems_task_wake_after( 1*TICKS_PER_SECOND );
+    status = rtems_task_wake_after( rtems_clock_get_ticks_per_second() );
     directive_failed( status, "rtems_task_wake_after of TA2" );
   }
 }
